@@ -5,6 +5,7 @@ from __future__ import annotations
 from typing import (
     Annotated,
     Any,
+    Awaitable,
     Callable,
     Iterator,
     Literal,
@@ -25,30 +26,16 @@ from pydantic import (
 )
 
 from dataservice._utils import _get_func_name
+from dataservice.config import ProxyConfig
 
 GenericDataItem = dict[Any, Any] | BaseModel
 RequestOrData = Union["Request", GenericDataItem]
 CallbackReturn = Iterator[RequestOrData] | RequestOrData
 CallbackType = Callable[["Response"], CallbackReturn]
-ClientCallable = Callable[["Request"], "Response"]
+ClientCallable = Callable[["Request"], Awaitable["Response"]]
 StrOrDict = str | dict
 
 
-class ProxyConfig(BaseModel):
-    """Proxy configuration for the service."""
-
-    host: str = Field(description="The proxy host.")
-    port: int = Field(description="The proxy port.")
-    username: Optional[str] = Field(description="The proxy username.", default=None)
-    password: Optional[str] = Field(description="The proxy password.", default=None)
-
-    @property
-    def url(self) -> str:
-        if self.username and self.password:
-            return f"http://{self.username}:{self.password}@{self.host}:{self.port}"
-        return f"http://{self.host}:{self.port}"
-
-
 class Request(BaseModel):
     """Request model."""
 
@@ -117,6 +104,15 @@ class Request(BaseModel):
     def client_name(self) -> str:
         return _get_func_name(self.client)
 
+    @property
+    def unique_key(self) -> str:
+        """Return a unique key for the request."""
+        return str(
+            hash(
+                f"{self.method} {self.url} {self.params} {self.json_data} {self.form_data}"
+            )
+        )
+
 
 class Response(BaseModel):
     """Response model."""
